@@ -31,6 +31,9 @@ from sklearn.metrics import precision_recall_curve
 from sklearn.metrics import average_precision_score
 from sklearn.metrics import plot_confusion_matrix
 
+from imblearn.ensemble import BalancedRandomForestClassifier
+from sklearn.datasets import make_classification
+
 from pptx.util import Pt
 from pptx.util import Inches
 
@@ -65,17 +68,11 @@ def get_equal_groups(data_df,group_count,variable_name):
     dict_df.columns = [col_name]
 
     temp_df = dict_df.reset_index(inplace=False)
-
-    min_df = min_df.round({col_name: 2})
-    max_df = max_df.round({col_name: 2})
-
     min_df = temp_df.groupby([col_name]).min().astype(str)
     max_df = temp_df.groupby([col_name]).max().astype(str)
 
     full_gp_name_df = pd.merge(min_df, max_df, left_index=True, right_index=True)
 
-
-
     full_gp_name_df[(col_name+'_rg')] = (full_gp_name_df['index_x']) + "-To-" + (full_gp_name_df['index_y'])
     return_df = pd.merge(full_gp_name_df, temp_df, left_on=col_name, right_on=col_name)
     return_df = return_df[[col_name,(col_name+'_rg'),'index']]
@@ -784,7 +781,7 @@ def make_ROC_graph(labels_test,prediction):
 # =======================================================
 #
 # =======================================================
-def run_classification(df,Label_Column,logger,is_forecast_flag,run_name,estimators,max_depth_i):
+def run_classification(df,Label_Column,logger,is_forecast_flag,run_name,estimators,max_depth_i,run_inbalance):
     """ Text """
     logger.info('========================================================')
     logger.info('========================================================')
@@ -830,12 +827,13 @@ def run_classification(df,Label_Column,logger,is_forecast_flag,run_name,estimato
 
     # ================================================================================================
     # ================================================================================================
-
-    clf = RandomForestClassifier(n_estimators=estimators,n_jobs=-1,verbose=1,max_depth=max_depth_i)
-    RandomForestClassifier
+	if run_inbalance == 1:
+		clf = BalancedRandomForestClassifier(n_estimators=estimators,n_jobs=-1,verbose=1,max_depth=max_depth_i)
+	if run_inbalance == 0:
+		clf = RandomForestClassifier(n_estimators=estimators,n_jobs=-1,verbose=1,max_depth=max_depth_i)
+	RandomForestClassifier
     logger.info("using RandomForestClassifier")
 
-
     # ================================================================================================
     # ================================================================================================
 
